==> portal-service-6.0.2-sources.jar: com/liferay/portal/kernel/lar/PortletDataHandlerKeys.java <==
/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.kernel.lar;

/**
 * <a href="PortletDataHandlerKeys.java.html"><b><i>View Source</i></b></a>
 *
 * @author Raymond Augé
 */
public class PortletDataHandlerKeys {

	public static final String CATEGORIES = "CATEGORIES";

	public static final String DATA_STRATEGY = "DATA_STRATEGY";

	public static final String DATA_STRATEGY_COPY_AS_NEW =
		"DATA_STRATEGY_COPY_AS_NEW";

	public static final String DATA_STRATEGY_MIRROR = "DATA_STRATEGY_MIRROR";

	public static final String DELETE_MISSING_LAYOUTS =
		"DELETE_MISSING_LAYOUTS";

	public static final String DELETE_PORTLET_DATA = "DELETE_PORTLET_DATA";

	public static final String LAYOUTS_IMPORT_MODE = "LAYOUTS_IMPORT_MODE";

	public static final String LAYOUTS_IMPORT_MODE_ADD_AS_NEW = "ADD_AS_NEW";

	public static final String LAYOUTS_IMPORT_MODE_MERGE_BY_LAYOUT_ID =
		"MERGE_BY_LAYOUT_ID";

	public static final String LAYOUTS_IMPORT_MODE_MERGE_BY_LAYOUT_NAME =
		"MERGE_BY_LAYOUT_NAME";

	public static final String PERMISSIONS = "PERMISSIONS";

	public static final String PORTLET_ARCHIVED_SETUPS =
		"PORTLET_ARCHIVED_SETUPS";

	public static final String PORTLET_DATA = "PORTLET_DATA";

	public static final String PORTLET_DATA_ALL = "PORTLET_DATA_ALL";

	public static final String PORTLET_DATA_CONTROL_DEFAULT =
		"PORTLET_DATA_CONTROL_DEFAULT";

	public static final String PORTLET_SETUP = "PORTLET_SETUP";

	public static final String PORTLET_USER_PREFERENCES =
		"PORTLET_USER_PREFERENCES";

	public static final String PORTLETS_MERGE_MODE = "PORTLETS_MERGE_MODE";

	public static final String PORTLETS_MERGE_MODE_ADD_TO_BOTTOM =
		"ADD_TO_BOTTOM";

	public static final String PORTLETS_MERGE_MODE_ADD_TO_TOP = "ADD_TO_TOP";

	public static final String PORTLETS_MERGE_MODE_REPLACE = "REPLACE";

	public static final String SELECTED_LAYOUTS = "SELECTED_LAYOUTS";

	public static final String THEME = "THEME";

	public static final String USER_ID_STRATEGY = "USER_ID_STRATEGY";

	public static final String USER_PERMISSIONS = "USER_PERMISSIONS";

}

==> portal-service-6.0.3-sources.jar: com/liferay/portal/kernel/lar/PortletDataHandlerKeys.java <==
/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.kernel.lar;

/**
 * @author Raymond Augé
 */
public class PortletDataHandlerKeys {

	public static final String CATEGORIES = "CATEGORIES";

	public static final String DATA_STRATEGY = "DATA_STRATEGY";

	public static final String DATA_STRATEGY_COPY_AS_NEW =
		"DATA_STRATEGY_COPY_AS_NEW";

	public static final String DATA_STRATEGY_MIRROR = "DATA_STRATEGY_MIRROR";

	public static final String DELETE_MISSING_LAYOUTS =
		"DELETE_MISSING_LAYOUTS";

	public static final String DELETE_PORTLET_DATA = "DELETE_PORTLET_DATA";

	public static final String IGNORE_LAST_PUBLISH_DATE =
		"IGNORE_LAST_PUBLISH_DATE";

	public static final String LAYOUTS_IMPORT_MODE = "LAYOUTS_IMPORT_MODE";

	public static final String LAYOUTS_IMPORT_MODE_ADD_AS_NEW = "ADD_AS_NEW";

	public static final String LAYOUTS_IMPORT_MODE_MERGE_BY_LAYOUT_ID =
		"MERGE_BY_LAYOUT_ID";

	public static final String LAYOUTS_IMPORT_MODE_MERGE_BY_LAYOUT_NAME =
		"MERGE_BY_LAYOUT_NAME";

	public static final String PERMISSIONS = "PERMISSIONS";

	public static final String PORTLET_ARCHIVED_SETUPS =
		"PORTLET_ARCHIVED_SETUPS";

	public static final String PORTLET_DATA = "PORTLET_DATA";

	public static final String PORTLET_DATA_ALL = "PORTLET_DATA_ALL";

	public static final String PORTLET_DATA_CONTROL_DEFAULT =
		"PORTLET_DATA_CONTROL_DEFAULT";

	public static final String PORTLET_SETUP = "PORTLET_SETUP";

	public static final String PORTLET_USER_PREFERENCES =
		"PORTLET_USER_PREFERENCES";

	public static final String PORTLETS_MERGE_MODE = "PORTLETS_MERGE_MODE";

	public static final String PORTLETS_MERGE_MODE_ADD_TO_BOTTOM =
		"ADD_TO_BOTTOM";

	public static final String PORTLETS_MERGE_MODE_ADD_TO_TOP = "ADD_TO_TOP";

	public static final String PORTLETS_MERGE_MODE_REPLACE = "REPLACE";

	public static final String SELECTED_LAYOUTS = "SELECTED_LAYOUTS";

	public static final String THEME = "THEME";

	public static final String USER_ID_STRATEGY = "USER_ID_STRATEGY";

	public static final String USER_PERMISSIONS = "USER_PERMISSIONS";

}
